@@ -4,27 +4,12 @@ package Net::ISC::DHCPd::OMAPI;
 
 Net::ISC::DHCPd::OMAPI - Talk to a dhcp server
 
-=head1 DESCRIPTION
-
-This module provides an API to query and possible change the ISC DHCPd
-server. The module use OMAPI (Object Management API) which does not
-require the server to be restarted for changes to apply.
-
-OMAPI is simply a communications mechanism that allows you to manipulate
-objects, which is stored in the dhcpd.leases file.
-
-See subclasses for more information about the different objects you can
-manipulate:
-L<Net::ISC::DHCPd::OMAPI::Failover>,
-L<Net::ISC::DHCPd::OMAPI::Group>,
-L<Net::ISC::DHCPd::OMAPI::Host>,
-and L<Net::ISC::DHCPd::OMAPI::Lease>.
-
 =head1 NOTE
 
-To enable debug output, execute this chunk of code before loading the module:
-
- BEGIN { Net::ISC::DHCPd::OMAPI::_DEBUG = sub { 1 } }
+ BEGIN {
+   Net::ISC::DHCPd::OMAPI::_DEBUG = sub { 1 }; # to enable debug output
+   use Net::ISC::DHCPd::OMAPI;
+ }
 
 =cut
 
@@ -210,14 +195,11 @@ Will open a connection to the dhcp server. Check C<$@> on failure.
 
 sub connect {
     my $self = shift;
-    my @commands = qw/port server/;
     my $buffer;
 
-    push @commands, 'key' if($self->key);
+    $self->errstr("");
 
-    $self->errstr('');
-
-    for my $attr (@commands) {
+    for my $attr (qw/port server key/) {
         $buffer = $self->_cmd(sprintf "%s %s", $attr, $self->$attr);
         last unless(defined $buffer);
     }
